Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5192)

Unified Diff: chrome/browser/extensions/api/web_request/web_request_api.cc

Issue 11826048: Revert 176015 (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Created 7 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/extensions/api/web_request/web_request_api.cc
===================================================================
--- chrome/browser/extensions/api/web_request/web_request_api.cc (revision 176046)
+++ chrome/browser/extensions/api/web_request/web_request_api.cc (working copy)
@@ -1706,7 +1706,7 @@
iter->second &= ~event_type;
}
// Special QuotaLimitHeuristic for WebRequestHandlerBehaviorChangedFunction.
//
// Each call of webRequest.handlerBehaviorChanged() clears the in-memory cache
// of WebKit at the time of the next page load (top level navigation event).
@@ -1955,7 +1955,7 @@
return true;
}
-void WebRequestHandlerBehaviorChangedFunction::GetQuotaLimitHeuristics(
+void WebRequestHandlerBehaviorChanged::GetQuotaLimitHeuristics(
QuotaLimitHeuristics* heuristics) const {
QuotaLimitHeuristic::Config config = {
// See web_request.json for current value.
@@ -1969,7 +1969,7 @@
heuristics->push_back(heuristic);
}
-void WebRequestHandlerBehaviorChangedFunction::OnQuotaExceeded(
+void WebRequestHandlerBehaviorChanged::OnQuotaExceeded(
const std::string& violation_error) {
// Post warning message.
ExtensionWarningSet warnings;
@@ -1985,7 +1985,7 @@
Run();
}
-bool WebRequestHandlerBehaviorChangedFunction::RunImpl() {
+bool WebRequestHandlerBehaviorChanged::RunImpl() {
helpers::ClearCacheOnNavigation();
return true;
}
@@ -1706,7 +1706,7 @@
iter->second &= ~event_type;
}
-// Special QuotaLimitHeuristic for WebRequestHandlerBehaviorChangedFunction.
+// Special QuotaLimitHeuristic for WebRequestHandlerBehaviorChanged.
//
// Each call of webRequest.handlerBehaviorChanged() clears the in-memory cache
« no previous file with comments | « chrome/browser/extensions/api/web_request/web_request_api.h ('k') | chrome/browser/extensions/browser_event_router.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698